@@ -7,7 +7,7 @@ from pydantic import BaseModel, Field, ConfigDict, field_validator
 
 from mixam_sdk.item_specification.enums.unit_format import UnitFormat
 from mixam_sdk.item_specification.interfaces.component_protocol import member_meta
-from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_value
 from mixam_sdk.utils.utils import MM_IN_INCH, get_b_format_from_custom_size
 
 
@@ -21,7 +21,7 @@ class CustomSize(BaseModel):
         "height": "h",
     }
 
-    unit_format: Annotated[UnitFormat, enum_by_name_or_value(UnitFormat), enum_dump_name] = Field(
+    unit_format: Annotated[UnitFormat, enum_by_name_or_value(UnitFormat), enum_dump_value] = Field(
         default=UnitFormat.METRIC,
         alias="unitFormat",
         description="Unit format used for the custom size. METRIC (mm) is 0, IMPERIAL (in) is 1",
