@@ -12,6 +12,8 @@ class EndPapersComponent(ComponentSupport):
 
     component_type: Literal[ComponentType.END_PAPERS] = Field(
         default=ComponentType.END_PAPERS,
+        alias="componentType",
+        validation_alias="componentType",
         frozen=True
     )
 
