@@ -1,9 +1,7 @@
 from __future__ import annotations
-
+from functools import cache
 from typing import List, Annotated, Union
-
 from pydantic import BaseModel, Field, ConfigDict, model_validator
-
 from mixam_sdk.item_specification.enums.colours import Colours
 from mixam_sdk.item_specification.enums.component_type import ComponentType
 from mixam_sdk.item_specification.enums.product import Product
@@ -12,16 +10,23 @@ from mixam_sdk.item_specification.models.bound_component import BoundComponent
 from mixam_sdk.item_specification.models.component_support import ComponentSupport
 from mixam_sdk.item_specification.models.cover_component import CoverComponent
 from mixam_sdk.item_specification.models.custom_size import CustomSize
-from mixam_sdk.item_specification.models.dust_jacket_component import DustJacketComponent
+from mixam_sdk.item_specification.models.dust_jacket_component import (
+    DustJacketComponent,
+)
 from mixam_sdk.item_specification.models.end_papers_component import EndPapersComponent
 from mixam_sdk.item_specification.models.envelope_component import EnvelopeComponent
 from mixam_sdk.item_specification.models.flat_component import FlatComponent
 from mixam_sdk.item_specification.models.folded_component import FoldedComponent
 from mixam_sdk.item_specification.models.framed_component import FramedComponent
-from mixam_sdk.item_specification.models.sample_pack_component import SamplePackComponent
-from mixam_sdk.item_specification.models.shrink_wrap_component import ShrinkWrapComponent
+from mixam_sdk.item_specification.models.sample_pack_component import (
+    SamplePackComponent,
+)
+from mixam_sdk.item_specification.models.shrink_wrap_component import (
+    ShrinkWrapComponent,
+)
 from mixam_sdk.item_specification.models.sticker_component import StickerComponent
 from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
+from mixam_sdk.ai_bridge import text_based
 
 ComponentUnion = Union[
     BoundComponent,
@@ -39,8 +44,8 @@ ComponentUnion = Union[
 
 ComponentTaggedUnion = Annotated[ComponentUnion, Field(discriminator="component_type")]
 
-class ItemSpecification(BaseModel):
 
+class ItemSpecification(BaseModel):
     copies: int = Field(
         default=1,
         description="Number of copies to be printed",
@@ -61,7 +66,7 @@ class ItemSpecification(BaseModel):
         extra="ignore",
         frozen=False,
         strict=True,
-        validate_assignment=True
+        validate_assignment=True,
     )
 
     @model_validator(mode="before")
@@ -103,15 +108,24 @@ class ItemSpecification(BaseModel):
         if not matched:
             raise RuntimeError(f"Component not found: {component_type}")
         if len(matched) > 1:
-            raise RuntimeError(f"There are multiple components of this type: {matched[0]}, {matched[1]}")
+            raise RuntimeError(
+                f"There are multiple components of this type: {matched[0]}, {matched[1]}"
+            )
         return matched[0]
 
     def get_component_by_code(self, component_type_code: str):
-        matched = [c for c in self.components if c.component_type.name == component_type_code or getattr(c.component_type, "code", None) == component_type_code]
+        matched = [
+            c
+            for c in self.components
+            if c.component_type.name == component_type_code
+            or getattr(c.component_type, "code", None) == component_type_code
+        ]
         if not matched:
             raise RuntimeError(f"Component not found by code: {component_type_code}")
         if len(matched) > 1:
-            raise RuntimeError(f"There are multiple components of this type: {matched[0]}, {matched[1]}")
+            raise RuntimeError(
+                f"There are multiple components of this type: {matched[0]}, {matched[1]}"
+            )
         return matched[0]
 
     def is_bound(self) -> bool:
@@ -136,8 +150,9 @@ class ItemSpecification(BaseModel):
         return front or back
 
     def requires_artwork(self) -> bool:
-        return any(getattr(c, "colours", Colours.NONE) != Colours.NONE for c in self.components)
-
+        return any(
+            getattr(c, "colours", Colours.NONE) != Colours.NONE for c in self.components
+        )
 
     def _clone(self) -> ItemSpecification:
         return self.model_copy(deep=True)
@@ -154,3 +169,26 @@ class ItemSpecification(BaseModel):
             for c in clone.components:
                 c.configure_size_custom(value)
         return clone
+
+    @classmethod
+    @cache
+    def text_based(cls: type[ItemSpecification]) -> type[ItemSpecification]:
+        return text_based(cls)
+
+    def to_text_based(self) -> ItemSpecification:
+        text_based_cls = type(self).text_based()
+        return text_based_cls(
+            copies=self.copies,
+            product=self.product.to_text_based(),
+            components=[component.to_text_based() for component in self.components],
+        )
+
+    @classmethod
+    def from_text_based(cls, text_based: ItemSpecification) -> ItemSpecification:
+        return cls(
+            copies=text_based.copies,
+            product=Product.from_text_based(text_based.product),
+            components=[
+                component.to_value_based() for component in text_based.components
+            ],
+        )
