@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict, computed_field
 
 from mixam_sdk.item_specification.enums.component_type import ComponentType
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class ComponentRequirement(BaseModel):
 
-    component_type: Annotated[ComponentType, enum_by_name(ComponentType), enum_dump_name] = Field(
+    component_type: Annotated[ComponentType, enum_by_name_or_value(ComponentType), enum_dump_name] = Field(
         alias="componentType",
     )
 
