@@ -9,7 +9,7 @@ from mixam_sdk.item_specification.models.item_specification import ItemSpecifica
 from mixam_sdk.metadata.product.enums.santa_type import SantaType
 from mixam_sdk.metadata.product.enums.trilean import Trilean
 from mixam_sdk.metadata.product.services.validation_result import ValidationResult
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 from .bound_metadata import BoundMetadata
 from .colours_metadata import ColoursMetadata
 from .component_requirement import ComponentRequirement
@@ -62,21 +62,6 @@ class ProductMetadata(BaseModel):
                 range_min=cm.minimum_value,
                 range_max=cm.maximum_value,
             )
-        else:
-            step = cm.step_value
-            if step > 0:
-                # Use initial_value as the step baseline when available (typical: 100),
-                # and always allow the exact minimum_value as a valid edge case.
-                baseline = cm.initial_value if cm.initial_value is not None else 0
-                aligned = ((copies - baseline) % step == 0) or (copies == cm.minimum_value)
-                if not aligned:
-                    result.add_error(
-                        path="copies",
-                        message=f"Copies {copies} does not align with step {step} from minimum {cm.minimum_value}.",
-                        code="copies.step_mismatch",
-                        range_min=cm.minimum_value,
-                        range_max=cm.maximum_value,
-                    )
 
         # Validate component type counts against requirements (top-level)
         try:
@@ -142,7 +127,7 @@ class ProductMetadata(BaseModel):
         except Exception:
             primary_validator = default_validator
         for idx, component in enumerate(spec.components):
-            base_path = f"components[{idx}]"
+            base_path = f"components[{component.component_type.name}]"
             if idx == primary_index:
                 # Apply primary-component-only rules first
                 primary_validator.validate(self, spec, component, result, base_path)
@@ -165,7 +150,7 @@ class ProductMetadata(BaseModel):
         alias="subProductId",
     )
 
-    santa_type: Annotated[SantaType, enum_by_name(SantaType), enum_dump_name] = Field(
+    santa_type: Annotated[SantaType, enum_by_name_or_value(SantaType), enum_dump_name] = Field(
         default=SantaType.QUOTE,
         alias="santaType",
     )
@@ -212,7 +197,7 @@ class ProductMetadata(BaseModel):
         alias="customSizeMetadata",
     )
 
-    default_orientation: Optional[Annotated[Orientation, enum_by_name(Orientation), enum_dump_name]] = Field(
+    default_orientation: Optional[Annotated[Orientation, enum_by_name_or_value(Orientation), enum_dump_name]] = Field(
         default=None,
         alias="defaultOrientation",
     )
@@ -240,7 +225,7 @@ class ProductMetadata(BaseModel):
         alias="preDrilledHolesMetadata",
     )
 
-    rounded_corners: Annotated[Trilean, enum_by_name(Trilean), enum_dump_name] = Field(
+    rounded_corners: Annotated[Trilean, enum_by_name_or_value(Trilean), enum_dump_name] = Field(
         default=Trilean.UNAVAILABLE,
         alias="roundedCorners",
     )
@@ -256,7 +241,6 @@ class ProductMetadata(BaseModel):
     initial_specification: ItemSpecification | None = Field(
         default=None,
         alias="initialSpecification",
-        exclude=True,
     )
 
     flap_metadata: Optional[FlapMetadata] = Field(
