@@ -5,13 +5,13 @@ from typing import Annotated, Optional
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.substrate_colour import SubstrateColour
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 from .substrate_weight_metadata import SubstrateWeightMetadata
 
 
 class SubstrateColourMetadata(BaseModel):
 
-    colour: Annotated[SubstrateColour, enum_by_name(SubstrateColour), enum_dump_name] = Field()
+    colour: Annotated[SubstrateColour, enum_by_name_or_value(SubstrateColour), enum_dump_name] = Field()
 
     id: int = Field()
 
