@@ -17,14 +17,7 @@ def enum_by_name_or_value(enum_cls: type[Enum]) -> Any:
         return ", ".join(items)
 
     def _to_enum(v):
-        # this hack is here because pydantic runs the validation twice per one `model_validate()` call
-        # once with correct, new Enum and once with the old one
-        enum_cls_or_tuple = (
-            (enum_cls, enum_cls.text_based())
-            if hasattr(enum_cls, "text_based")
-            else enum_cls
-        )
-        if isinstance(v, enum_cls_or_tuple):
+        if isinstance(v, enum_cls):
             return v
         if isinstance(v, str):
             try:
